@@ -21,13 +21,22 @@ from typing import Optional, Tuple
 
 from flwr.common import GRPC_MAX_MESSAGE_LENGTH
 from flwr.common.logger import log
+from flwr.proto.driver_pb2_grpc import add_DriverServicer_to_server
+from flwr.proto.transport_pb2_grpc import add_FlowerServiceServicer_to_server
 from flwr.server.client_manager import ClientManager, SimpleClientManager
-from flwr.server.grpc_server.grpc_server import start_grpc_server
+from flwr.server.driver.driver_servicer import DriverServicer
+from flwr.server.grpc_server.flower_service_servicer import FlowerServiceServicer
+from flwr.server.grpc_server.grpc_server import (
+    generic_create_grpc_server,
+    start_grpc_server,
+)
 from flwr.server.history import History
 from flwr.server.server import Server
 from flwr.server.strategy import FedAvg, Strategy
 
 DEFAULT_SERVER_ADDRESS = "[::]:8080"
+DEFAULT_SERVER_ADDRESS_DRIVER = "[::]:9091"
+DEFAULT_SERVER_ADDRESS_FLEET = "[::]:9092"
 
 
 @dataclass
@@ -54,43 +63,46 @@ def start_server(  # pylint: disable=too-many-arguments
 ) -> History:
     """Start a Flower server using the gRPC transport layer.
 
-    Arguments
-    ---------
-        server_address: Optional[str] (default: `"[::]:8080"`). The IPv6
-            address of the server.
-        server: Optional[flwr.server.Server] (default: None). An implementation
-            of the abstract base class `flwr.server.Server`. If no instance is
-            provided, then `start_server` will create one.
-        config: ServerConfig (default: None).
-            Currently supported values are `num_rounds` (int, default: 1) and
-            `round_timeout` in seconds (float, default: None).
-        strategy: Optional[flwr.server.Strategy] (default: None). An
-            implementation of the abstract base class `flwr.server.Strategy`.
-            If no strategy is provided, then `start_server` will use
-            `flwr.server.strategy.FedAvg`.
-        client_manager: Optional[flwr.server.ClientManager] (default: None)
-            An implementation of the abstract base class `flwr.server.ClientManager`.
-            If no implementation is provided, then `start_server` will use
-            `flwr.server.client_manager.SimpleClientManager`.
-        grpc_max_message_length: int (default: 536_870_912, this equals 512MB).
-            The maximum length of gRPC messages that can be exchanged with the
-            Flower clients. The default should be sufficient for most models.
-            Users who train very large models might need to increase this
-            value. Note that the Flower clients need to be started with the
-            same value (see `flwr.client.start_client`), otherwise clients will
-            not know about the increased limit and block larger messages.
-        certificates : Tuple[bytes, bytes, bytes] (default: None)
-            Tuple containing root certificate, server certificate, and private key to
-            start a secure SSL-enabled server. The tuple is expected to have three bytes
-            elements in the following order:
+    Parameters
+    ----------
+    server_address : Optional[str]
+        The IPv4 or IPv6 address of the server. Defaults to `"[::]:8080"`.
+    server : Optional[flwr.server.Server] (default: None)
+        A server implementation, either `flwr.server.Server` or a subclass
+        thereof. If no instance is provided, then `start_server` will create
+        one.
+    config : Optional[ServerConfig] (default: None)
+        Currently supported values are `num_rounds` (int, default: 1) and
+        `round_timeout` in seconds (float, default: None).
+    strategy : Optional[flwr.server.Strategy] (default: None).
+        An implementation of the abstract base class
+        `flwr.server.strategy.Strategy`. If no strategy is provided, then
+        `start_server` will use `flwr.server.strategy.FedAvg`.
+    client_manager : Optional[flwr.server.ClientManager] (default: None)
+        An implementation of the abstract base class
+        `flwr.server.ClientManager`. If no implementation is provided, then
+        `start_server` will use
+        `flwr.server.client_manager.SimpleClientManager`.
+    grpc_max_message_length : int (default: 536_870_912, this equals 512MB)
+        The maximum length of gRPC messages that can be exchanged with the
+        Flower clients. The default should be sufficient for most models.
+        Users who train very large models might need to increase this
+        value. Note that the Flower clients need to be started with the
+        same value (see `flwr.client.start_client`), otherwise clients will
+        not know about the increased limit and block larger messages.
+    certificates : Tuple[bytes, bytes, bytes] (default: None)
+        Tuple containing root certificate, server certificate, and private key
+        to start a secure SSL-enabled server. The tuple is expected to have
+        three bytes elements in the following order:
 
-                * CA certificate.
-                * server certificate.
-                * server private key.
+            * CA certificate.
+            * server certificate.
+            * server private key.
 
     Returns
     -------
-        hist: flwr.server.history.History. Object containing metrics from training.
+    hist : flwr.server.history.History
+        Object containing training and evaluation metrics.
 
     Examples
     --------
@@ -98,7 +110,7 @@ def start_server(  # pylint: disable=too-many-arguments
 
     >>> start_server()
 
-    Starting a SSL-enabled server:
+    Starting an SSL-enabled server:
 
     >>> start_server(
     >>>     certificates=(
@@ -186,3 +198,52 @@ def _fl(
     server.disconnect_all_clients(timeout=config.round_timeout)
 
     return hist
+
+
+def run_server() -> None:
+    """Run Flower server."""
+    log(INFO, "Starting Flower server")
+
+    client_manager: ClientManager = SimpleClientManager()
+
+    # Create Driver API gRPC server
+    driver_server_address: str = DEFAULT_SERVER_ADDRESS_DRIVER
+    driver_servicer = DriverServicer(client_manager=client_manager)
+    driver_add_servicer_to_server_fn = add_DriverServicer_to_server
+    driver_grpc_server = generic_create_grpc_server(
+        servicer_and_add_fn=(driver_servicer, driver_add_servicer_to_server_fn),
+        server_address=driver_server_address,
+        max_message_length=GRPC_MAX_MESSAGE_LENGTH,
+        certificates=None,
+    )
+
+    # Create (legacy) Fleet API gRPC server
+    fleet_server_address: str = DEFAULT_SERVER_ADDRESS_FLEET
+    fleet_servicer = FlowerServiceServicer(client_manager=client_manager)
+    fleet_add_servicer_to_server_fn = add_FlowerServiceServicer_to_server
+    fleet_grpc_server = generic_create_grpc_server(
+        servicer_and_add_fn=(fleet_servicer, fleet_add_servicer_to_server_fn),
+        server_address=fleet_server_address,
+        max_message_length=GRPC_MAX_MESSAGE_LENGTH,
+        certificates=None,
+    )
+
+    # Start Driver API gRPC server
+    driver_grpc_server.start()
+    log(
+        INFO,
+        "Flower ECE: driver gRPC server running on %s",
+        driver_server_address,
+    )
+
+    # Start (legacy) Fleet API gRPC server
+    fleet_grpc_server.start()
+    log(
+        INFO,
+        "Flower ECE: fleet gRPC server running on %s",
+        fleet_server_address,
+    )
+
+    # Wait for termination of both servers
+    driver_grpc_server.wait_for_termination()
+    fleet_grpc_server.wait_for_termination()
