@@ -21,6 +21,7 @@ from .fedadam import FedAdam as FedAdam
 from .fedavg import FedAvg as FedAvg
 from .fedavg_android import FedAvgAndroid as FedAvgAndroid
 from .fedavgm import FedAvgM as FedAvgM
+from .fedmedian import FedMedian as FedMedian
 from .fedopt import FedOpt as FedOpt
 from .fedyogi import FedYogi as FedYogi
 from .qfedavg import QFedAvg as QFedAvg
@@ -36,5 +37,6 @@ __all__ = [
     "FedOpt",
     "FedYogi",
     "QFedAvg",
+    "FedMedian",
     "Strategy",
 ]
